@@ -11,13 +11,9 @@
 #include <config.h>
 
 #include "flist.h"
-#include "flist-completion.h"
 #include "flist-icon-list.h"
-#include "flist-entry.h"
 #include "flist-table.h"
 
-#include "GNOME_FileList.h"
-
 #include <bonobo/bonobo-control.h>
 #include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-shlib-factory.h>
@@ -41,8 +37,6 @@
 #include <libgnomevfs/gnome-vfs-mime.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 
-#include <sys/timeb.h>
-
 #define PARENT_TYPE BONOBO_X_OBJECT_TYPE
 
 #define d(x)
@@ -50,7 +44,7 @@
 enum {
 	PROP_ACCEPT_DIRS,
 	PROP_CURRENT_WORKING_URI,
-	PROP_LOCAL_URIS_ONLY,
+	PROP_ENABLE_VFS,
 	PROP_MIME_TYPES,
 	PROP_MULTI_SELECT,
 	PROP_REQUESTED_URI,
@@ -62,7 +56,7 @@ enum {
 static const char *prop_name[] = {
 	"AcceptDirectories",
 	"CurrentWorkingURI",
-	"LocalURIsOnly",
+	"EnableVFS",
 	"MimeTypes",
 	"MultipleSelection",
 	"RequestedURI",
@@ -73,7 +67,7 @@ static const char *prop_name[] = {
 static const char *prop_desc[] = {
 	N_("Calling application can accept directories"),
 	N_("URI currently displayed"),
-	N_("Restrict files to local URIs only"),
+	N_("Allow gnome-vfs aware URIs"),
 	N_("Mime types displayed"),
 	N_("Enable multiple selection of files"),
 	N_("URI currently being requested"),
@@ -84,7 +78,7 @@ static const char *prop_desc[] = {
 enum {
 	SIGNAL_URI_CHANGED,
 	SIGNAL_URI_REQUESTED,
-	SIGNAL_LOCAL_ONLY_CHANGED,
+	SIGNAL_ENABLE_VFS_CHANGED,
 	SIGNAL_LOAD_CANCELLED,
 	SIGNAL_MIME_TYPES_CHANGED,
 	SIGNAL_MULTI_SELECT_CHANGED,
@@ -130,8 +124,6 @@ struct _FListPrivate {
 	GtkWidget     *type_combo;
 	BonoboObject  *type_control;
 	
-	FListEntry    *entry;
-
 	FListView      view;
 
 	gboolean       multi_select;
@@ -140,7 +132,7 @@ struct _FListPrivate {
 
 	char         **mime_types;
 	gboolean       accept_dirs;
-	gboolean       local_only;
+	gboolean       enable_vfs;
 
 	char            *requested_uri;
 	FListRequestType requested_uri_type;
@@ -186,7 +178,7 @@ flist_report_error (FList *flist, const char *error)
 	arg = bonobo_arg_new (BONOBO_ARG_STRING);
 	BONOBO_ARG_SET_STRING (arg, error);
 	bonobo_event_source_notify_listeners_full (flist->priv->es,
-						   "GNOME/FileList",
+						   "GNOME/FileSelector/List",
 						   "Error",
 						   NULL,
 						   arg, NULL);
@@ -200,9 +192,15 @@ flist_get_multi_select (FList *flist)
 }
 
 gboolean
-flist_get_local_only (FList *flist)
+flist_get_accept_dirs (FList *flist)
 {
-	return flist->priv->local_only;
+	return flist->priv->accept_dirs;
+}
+
+gboolean
+flist_get_vfs_enabled (FList *flist)
+{
+	return flist->priv->enable_vfs;
 }
 
 GnomeVFSDirectoryFilter *
@@ -250,6 +248,8 @@ flist_request_uri (FList *flist, const char *uri, FListRequestType rtype)
 void
 flist_set_current_uri (FList *flist, const char *uri)
 {
+	int len;
+
 	g_return_if_fail (IS_FLIST (flist));
 	g_return_if_fail (uri != NULL);
 
@@ -258,7 +258,11 @@ flist_set_current_uri (FList *flist, const char *uri)
 	flist->priv->requested_uri = NULL;
 
 	g_free (flist->priv->current_uri);
-	flist->priv->current_uri = g_strdup (uri);
+
+	len = strlen (uri);
+	flist->priv->current_uri = 
+		g_strconcat (uri, uri[len - 1] == '/' ? NULL : "/", NULL);
+
 	gtk_signal_emit (GTK_OBJECT (flist), 
 			 flist_signal[SIGNAL_URI_CHANGED], 
 			 flist->priv->current_uri);
@@ -296,7 +300,7 @@ flist_set_view (FList *flist, FListView view)
 		break;
 	default:
 		g_warning ("not yet supported");
-		break;
+		return;
 	}
 
 	flist->priv->view = view;
@@ -326,12 +330,12 @@ flist_set_prop (BonoboPropertyBag *bag,
 	case PROP_ACCEPT_DIRS:
 		flist->priv->accept_dirs = BONOBO_ARG_GET_BOOLEAN (arg);
 		break;
-	case PROP_LOCAL_URIS_ONLY:
+	case PROP_ENABLE_VFS:
 		i = BONOBO_ARG_GET_BOOLEAN (arg);
-		if (flist->priv->local_only == i)
+		if (flist->priv->enable_vfs == i)
 			return;
-		flist->priv->local_only = i;
-		gtk_signal_emit (GTK_OBJECT (flist), flist_signal[SIGNAL_LOCAL_ONLY_CHANGED], i);
+		flist->priv->enable_vfs = i;
+		gtk_signal_emit (GTK_OBJECT (flist), flist_signal[SIGNAL_ENABLE_VFS_CHANGED], i);
 		break;
 	case PROP_MIME_TYPES:
 		s = BONOBO_ARG_GET_STRING (arg);
@@ -362,13 +366,6 @@ flist_set_prop (BonoboPropertyBag *bag,
 		}
 		bonobo_exception_set (ev, ex_Bonobo_Property_InvalidValue);
 		break;
-	default:
-		/* until bonobo sets this exception */
-		if (arg_id >= 0 && arg_id < PROP_LAST)
-			bonobo_exception_set (ev, ex_Bonobo_Property_ReadOnlyProperty);
-		else
-			g_assert_not_reached ();
-		break;
 	}
 }
 
@@ -390,8 +387,8 @@ flist_get_prop (BonoboPropertyBag *bag,
 	case PROP_CURRENT_WORKING_URI:
 		BONOBO_ARG_SET_STRING (arg, flist->priv->current_uri);
 		break;
-	case PROP_LOCAL_URIS_ONLY:
-		BONOBO_ARG_SET_BOOLEAN (arg, flist->priv->local_only);
+	case PROP_ENABLE_VFS:
+		BONOBO_ARG_SET_BOOLEAN (arg, flist->priv->enable_vfs);
 		break;
 	case PROP_MIME_TYPES:
 		s = flist->priv->mime_types
@@ -423,9 +420,6 @@ flist_get_prop (BonoboPropertyBag *bag,
 		}
 		BONOBO_ARG_SET_INT (arg, i);
 		break;
-	default:
-		bonobo_exception_set (ev, ex_Bonobo_PropertyBag_NotFound);
-		break;
 	}
 }
 
@@ -451,9 +445,6 @@ flist_destroy (GtkObject *object)
 	if (priv->type_control)
 		bonobo_object_unref (priv->type_control);
 
-	if (priv->entry)
-		flist_entry_free (priv->entry);
-
 	g_free (priv->current_uri);
 
 	if (priv->mime_types)
@@ -467,30 +458,6 @@ flist_destroy (GtkObject *object)
 	parent_class->destroy (object);
 }
 
-static GNOME_FileList_URIList *
-impl_getSelectedURIs (PortableServer_Servant servant, 
-		      CORBA_Environment *ev)
-{
-	CORBA_sequence_CORBA_string *seq = NULL;
-	FList *flist;
-
-	flist = FLIST (BONOBO_X_SERVANT_GET_OBJECT (servant));
-
-	switch (flist->priv->view) {
-	case VIEW_DETAILS:
-		seq = flist_table_get_selected_uris (flist->priv->w_view);
-		break;
-	case VIEW_ICONS:
-		seq = flist_icon_list_get_selected_uris (flist->priv->w_view);
-		break;
-	default:
-		g_assert_not_reached ();
-		break;
-	}
-
-	return seq;
-}
-
 static Bonobo_Control
 impl_getTypeSelectorControl (PortableServer_Servant servant, 
 			     CORBA_Environment *ev)
@@ -501,20 +468,31 @@ impl_getTypeSelectorControl (PortableServer_Servant servant,
 	return bonobo_object_dup_ref (BONOBO_OBJREF (flist->priv->type_control), ev);
 }
 
-static Bonobo_Control
-impl_getFileCompletionControl (PortableServer_Servant servant,
-			       CORBA_Environment *ev)
+static void
+impl_activateSelectedURIs (PortableServer_Servant servant,
+			   CORBA_Environment *ev)
 {
 	FList *flist;
+
 	flist = FLIST (BONOBO_X_SERVANT_GET_OBJECT (servant));
 
-	return bonobo_object_dup_ref (BONOBO_OBJREF (flist->priv->entry->control), ev);
+	switch (flist->priv->view) {
+	case VIEW_DETAILS:
+		flist_table_activate_selected_uris (flist->priv->w_view);
+		break;
+	case VIEW_ICONS:
+		flist_icon_list_activate_selected_uris (flist->priv->w_view);
+		break;
+	default:
+		g_assert_not_reached ();
+		break;
+	}
 }
 
 static void
 impl_requestURI (PortableServer_Servant servant,
 		 const char *uri,
-		 GNOME_FileList_RequestType rtype,
+		 GNOME_FileSelector_List_RequestType rtype,
 		 CORBA_Environment *ev)
 {
 	FList *flist;
@@ -524,6 +502,30 @@ impl_requestURI (PortableServer_Servant servant,
 	flist_request_uri (flist, uri, rtype);
 }
 
+static GNOME_FileSelector_List_URIList *
+impl_getSelectedURIs (PortableServer_Servant servant, 
+                      CORBA_Environment *ev)
+{
+        CORBA_sequence_CORBA_string *seq = NULL;
+        FList *flist;
+
+        flist = FLIST (BONOBO_X_SERVANT_GET_OBJECT (servant));
+
+        switch (flist->priv->view) {
+        case VIEW_DETAILS:
+                seq = flist_table_get_selected_uris (flist->priv->w_view);
+                break;
+        case VIEW_ICONS:
+                seq = flist_icon_list_get_selected_uris (flist->priv->w_view);
+                break;
+        default:
+                g_assert_not_reached ();
+                break;
+        }
+
+        return seq;
+}
+
 static void
 flist_uri_changed (FList *flist, const char *uri)
 {
@@ -606,11 +608,11 @@ flist_class_init (GtkObjectClass *object_class)
 				gtk_marshal_NONE__NONE,
 				GTK_TYPE_NONE, 0);
 
-	flist_signal[SIGNAL_LOCAL_ONLY_CHANGED] = 
-		gtk_signal_new ("local_only_changed",
+	flist_signal[SIGNAL_ENABLE_VFS_CHANGED] = 
+		gtk_signal_new ("enable_vfs_changed",
 				GTK_RUN_FIRST,
 				object_class->type,
-				GTK_SIGNAL_OFFSET (FListClass, local_only_changed),
+				GTK_SIGNAL_OFFSET (FListClass, enable_vfs_changed),
 				gtk_marshal_NONE__BOOL,
 				GTK_TYPE_NONE, 1, GTK_TYPE_BOOL);
 
@@ -635,28 +637,15 @@ flist_class_init (GtkObjectClass *object_class)
 	flist_class->uri_changed   = flist_uri_changed;
 	flist_class->uri_requested = flist_uri_requested;
 
-	flist_class->epv.getSelectedURIs          = impl_getSelectedURIs;
-	flist_class->epv.getFileCompletionControl = impl_getFileCompletionControl;
 	flist_class->epv.getTypeSelectorControl   = impl_getTypeSelectorControl;
+	flist_class->epv.activateSelectedURIs     = impl_activateSelectedURIs;
+	flist_class->epv.getSelectedURIs          = impl_getSelectedURIs;
 	flist_class->epv.cancelLoading            = impl_cancelLoading;
 	flist_class->epv.requestURI               = impl_requestURI;
 
 
-	if (!gnome_vfs_initialized ()) {
-#if 1
+	if (!gnome_vfs_initialized ())
 		gnome_vfs_init ();
-#else
-		struct timeb tp1, tp2;
-
-		ftime (&tp1);
-
-		ftime (&tp2);
-
-		g_print ("gnome_vfs_init() took %f seconds.\n",
-			 (tp2.time + (tp2.millitm / 1000.0)) -
-			 (tp1.time + (tp1.millitm / 1000.0)));
-#endif
-	}
 }
 
 static void
@@ -720,42 +709,19 @@ create_type_combo (FList *flist)
 	flist->priv->type_control = BONOBO_OBJECT (bonobo_control_new (flist->priv->type_combo));
 }
 
-static void
-create_completion (FList *flist)
-{
-	flist->priv->entry = flist_entry_new (flist);
-}
-
-FListCompletion *
-flist_get_completion (FList *flist)
-{
-	g_return_val_if_fail (flist != NULL, NULL);
-
-	return flist->priv->entry->completion;
-}
-
 void
 flist_uris_activated (FList *flist, CORBA_sequence_CORBA_string *seq)
 {
 	CORBA_any any;
-	int i;
-
-#if 0
-	g_print ("(flist) files activated:\n"));
-	for (i=0; i < seq->_length; i++)
-		g_print ("\t%s\n", seq->_buffer[i]);
-	g_print ("\n");
-#endif
 
 	any._type = TC_CORBA_sequence_CORBA_string;
 	any._value = seq;
 	any._release = FALSE;
 
 	bonobo_event_source_notify_listeners_full (flist->priv->es,
-						   "GNOME/FileList",
+						   "GNOME/FileSelector/List",
 						   "URIsActivated",
-						   NULL,
-						   &any, NULL);
+						   NULL, &any, NULL);
 	CORBA_free (seq);
 }
 
@@ -774,7 +740,7 @@ add_properties (FList *flist, BonoboControl *control)
 
 	ADD_PROP (PROP_ACCEPT_DIRS,         BONOBO_ARG_BOOLEAN, RW);
 	ADD_PROP (PROP_CURRENT_WORKING_URI, BONOBO_ARG_STRING,  RO);
-	ADD_PROP (PROP_LOCAL_URIS_ONLY,     BONOBO_ARG_BOOLEAN, RW);
+	ADD_PROP (PROP_ENABLE_VFS,          BONOBO_ARG_BOOLEAN, RW);
 	ADD_PROP (PROP_MIME_TYPES,          BONOBO_ARG_STRING,  RW);
 	ADD_PROP (PROP_MULTI_SELECT,        BONOBO_ARG_BOOLEAN, RW);
 	ADD_PROP (PROP_REQUESTED_URI,       BONOBO_ARG_STRING,  RW);
@@ -793,6 +759,8 @@ flist_init (GtkObject *object)
 
 	flist->priv = g_new0 (FListPrivate, 1);
 
+	flist->priv->enable_vfs = TRUE;
+
 	/*
 	 * The notebook where we place the various file listing views
 	 */
@@ -803,7 +771,6 @@ flist_init (GtkObject *object)
 	 * Setup the directory listing
 	 */
 	create_type_combo (flist);
-	create_completion (flist);
 
 	/* we shouldn't set view until we have a dir and a combo */
 	flist_set_view (flist, VIEW_DETAILS);
@@ -819,15 +786,4 @@ flist_init (GtkObject *object)
 	add_properties (flist, control);
 }
 
-BONOBO_X_TYPE_FUNC_FULL(FList, GNOME_FileList, PARENT_TYPE, flist);
-
-static BonoboObject *
-create_flist (BonoboGenericFactory *factory, gpointer data)
-{
-	return BONOBO_OBJECT (gtk_type_new (FLIST_TYPE));
-}
-
-BONOBO_OAF_SHLIB_FACTORY ("OAFIID:GNOME_FileList_ControlFactory",
-			  "File selector list",
-			  create_flist,
-			  NULL);
+BONOBO_X_TYPE_FUNC_FULL(FList, GNOME_FileSelector_List, PARENT_TYPE, flist);
